@@ -4,16 +4,9 @@
 
 #include <server/pg_config.h>
 
-#define SLONY_I_VERSION_STRING	"2.2.1"
-#define SLONY_I_VERSION_STRING_DEC 2,2,1
-#define SLONY_I_FUNC_VERSION_STRING 2_2_1
-
-#if PG_VERSION_NUM >= 90300
-#define HAVE_GETACTIVESNAPSHOT 1
-#define HAVE_TYPCACHE 1
-#define SETCONFIGOPTION_7 1
-#define HAS_LOOKUPEXPLICITNAMESPACE_2 1
-#elif PG_VERSION_NUM >= 90200
+#define SLONY_I_VERSION_STRING	"2.1.1"
+#define SLONY_I_VERSION_STRING_DEC 2,1,1
+#if PG_VERSION_NUM >= 90200
 #define HAVE_GETACTIVESNAPSHOT 1
 #define HAVE_TYPCACHE 1
 #define SETCONFIGOPTION_7 1
