@@ -28,6 +28,7 @@ void build_conf_variables(void);
 
 static struct config_int ConfigureNamesInt[] =
 {
+
 	{
 		{
 			(const char *) "vac_frequency",		/* conf name */
@@ -67,8 +68,8 @@ static struct config_int ConfigureNamesInt[] =
 	{
 		{
 			(const char *) "sync_interval_timeout",
-			gettext_noop("sync interval time out"),
-			gettext_noop("sync interval time out"),
+			gettext_noop("sync interval time out - milliseconds"),
+			gettext_noop("sync interval time out - milliseconds"),
 			SLON_C_INT
 		},
 		&sync_interval_timeout,
@@ -132,19 +133,6 @@ static struct config_int ConfigureNamesInt[] =
 		0,
 		2147483647
 	},
-	{
-		{
-			(const char *) "quit_sync_finalsync",
-			gettext_noop("SYNC number at which slon should abort"),
-			gettext_noop("We want to terminate slon when the worker thread reaches a certain SYNC number "
-				 "against a certain provider.  This is the SYNC number... "),
-			SLON_C_INT
-		},
-		&quit_sync_finalsync,
-		0,
-		0,
-		2147483647
-	},
 	{
 		{
 			(const char *) "sync_max_rowsize",	/* conf name */
@@ -182,8 +170,76 @@ static struct config_int ConfigureNamesInt[] =
 		30,						/* min val */
 		30000					/* max val */
 	},
-
-
+	{
+		{
+			(const char *) "monitor_interval",
+			gettext_noop("monitor thread interval for dumping the state queue"),
+			gettext_noop("number of milliseconds monitor thread waits to queue up status entries"),
+			SLON_C_INT
+		},
+		&monitor_interval,
+		500,
+		10,
+		12000
+	},
+	{
+		{	  
+			(const char *) "explain_interval",		/* conf name */
+			gettext_noop("Interval in seconds in which the remote worker will report an explain of the log selection query"),		/* short desc */
+			gettext_noop("Interval in seconds in which the remote worker will report an explain of the log selection query"),		/* long desc */
+			SLON_C_INT			/* config type */
+	    },
+		&explain_interval, /* var name */
+		0,						/* default val (never) */
+		0,						/* min val */
+		86400					/* max val (1 day) */
+	},
+		{
+		{
+			(const char*) "tcp_keepalive_idle",
+			gettext_noop("The number of seconds after which a TCP keep alive "
+						 "is sent across an idle connection. tcp_keepalive "
+						 "must be enabled for this to take effect.  Default "
+						 "of 0 means use operating system default"
+						 "use default" ),
+			NULL,
+			SLON_C_INT,
+		},
+		&keep_alive_idle,
+		0, /*default val */
+		0, /* min val */
+		1073741824	/*max val*/
+	},
+	{
+		{
+			(const char*) "tcp_keepalive_interval",
+			gettext_noop("The number of seconds in between TCP keep alive "
+						 "requests. tcp_keepalive "
+						 "must be enabled. Default value of 0 means use "
+                         "operating system defaut"),
+			NULL,
+			SLON_C_INT,
+		},
+		&keep_alive_interval,
+		0,
+		0, /* min val */
+		1073741824	/*max val*/
+	},
+	{
+		{
+			(const char*) "tcp_keepalive_count",
+			gettext_noop("The number of keep alive requests to the server "
+						 "that can be lost before the connection is declared "
+						 "dead. tcp_keep_alive must be on. Default value "
+						 "of 0 means use operating system default"),
+			NULL,
+			SLON_C_INT,
+		},
+		&keep_alive_count,
+		0,
+		0, /* min val */
+		1073741824	/*max val*/
+	},
 	{{0}}
 };
 
@@ -210,17 +266,28 @@ static struct config_bool ConfigureNamesBool[] =
 		true
 	},
 
+	{  
+	
+		{
+			(const char*) "tcp_keepalive",
+			gettext_noop("Enables sending of TCP KEEP alive between slon "
+						 "and the PostgreSQL backends. "),
+			NULL,
+			SLON_C_BOOL,
+		},
+		&keep_alive,
+		true
+	},
 	{
 		{
-			(const char *) "cleanup_deletelogs",
-			gettext_noop("Should the cleanup thread DELETE sl_log_? entries or not"),
-			gettext_noop("Should the cleanup thread DELETE sl_log_? entries or leave trimming to the TRUNCATE"),
-			SLON_C_BOOL
+			(const char*) "monitor_threads",
+			gettext_noop("Should the monitoring thread be run?"),
+			NULL,
+			SLON_C_BOOL,
 		},
-		&cleanup_deletelogs,
-		false
+		&monitor_threads,
+		true
 	},
-
 	{{0}}
 };
 
@@ -277,11 +344,11 @@ static struct config_string ConfigureNamesString[] =
 		{
 			(const char *) "log_timestamp_format",
 			gettext_noop("A strftime()-style log timestamp format string."),
-			NULL,
+			gettext_noop("If modified, a trailing space to separate this from the next field is likely wanted."),
 			SLON_C_STRING
 		},
 		&log_timestamp_format,
-		"%Y-%m-%d %H:%M:%S %Z"
+		"%Y-%m-%d %H:%M:%S %Z "
 	},
 	{
 		{
@@ -307,7 +374,6 @@ static struct config_string ConfigureNamesString[] =
 		NULL
 	},
 
-
 	{
 		{
 			(const char *) "lag_interval",
@@ -651,6 +717,7 @@ parse_bool(const char *value, bool *result)
 	return true;
 }
 
+
 /*
  * Try to parse value as an integer.  The accepted formats are the usual
  * decimal, octal, or hexadecimal formats.	If the string parses okay, return
@@ -662,6 +729,7 @@ parse_int(const char *value, int *result)
 	long		val;
 	char	   *endptr;
 
+
 	errno = 0;
 	val = strtol(value, &endptr, 0);
 
@@ -677,6 +745,7 @@ parse_int(const char *value, int *result)
 	return true;
 }
 
+
 /*
  * Try to parse value as a floating point constant in the usual format.
  * If the value parsed okay return true, else false.  If result is not NULL,
