@@ -4,8 +4,6 @@
  * Functions in misc.c
  * ----------
  */
-#include "config.h"
-#include "c.h"
 
 typedef enum
 {
@@ -36,6 +34,13 @@ extern int	slon_scanint64(char *str, int64 * result);
 #undef send
 #endif
 
+/* Adjustment windows */
+#ifdef WIN32
+#define sleep(x) Sleep(x*1000)
+#define strtoll(x,y,z) (__int64) strtol(x,y,z)
+#define strncasecmp(x,y,z)	strnicmp(x,y,z)
+#endif
+
 /*
  * Local Variables:
  *	tab-width: 4
