@@ -17,14 +17,20 @@
 #include <sys/types.h>
 #include <sys/wait.h>
 #endif
-#include "libpq-fe.h"
+
 #include <stdarg.h>
-#include<string.h>
+#include <string.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include "types.h"
-#include "slonik.h"
 
+#ifdef WIN32
+#include "config_msvc.h"
+#else
+#include "config.h"
+#endif
+#include "types.h"
+#include "libpq-fe.h"
+#include "slonik.h"
 
 /*
  * Global data
@@ -32,6 +38,7 @@
 int			db_notice_silent = false;
 SlonikStmt *db_notice_stmt = NULL;
 
+extern int current_try_level;
 
 /*
  * Local functions
@@ -113,6 +120,7 @@ db_connect(SlonikStmt * stmt, SlonikAdmInfo * adminfo)
 {
 	PGconn	   *dbconn;
 	SlonDString	query;
+	PGresult   *res;
 
 	db_notice_stmt = stmt;
 
@@ -157,6 +165,7 @@ db_connect(SlonikStmt * stmt, SlonikAdmInfo * adminfo)
 	slon_mkquery(&query,"SET datestyle TO 'ISO'; "
 						"SET session_replication_role TO local; ");
 
+
 	adminfo->dbconn = dbconn;
 	if (db_exec_command(stmt, adminfo, &query) < 0)
 	{
@@ -164,8 +173,33 @@ db_connect(SlonikStmt * stmt, SlonikAdmInfo * adminfo)
 		dstring_free(&query);
 		return -1;
 	}
+	dstring_free(&query);
+
+	dstring_init(&query);
+	slon_mkquery(&query,"select 1 from pg_catalog.pg_settings where name= 'application_name'; ");
+	res = db_exec_select (stmt, adminfo, &query);
+
+	if (res == NULL)
+			return -1;
+
 	dstring_free(&query); 
 
+	if (PQntuples(res) == 0)
+	{
+			/* Unable to set application_name on this version of PostgreSQL */
+			PQclear(res);
+	} else {
+			PQclear(res);
+			dstring_init(&query);
+			slon_mkquery(&query,"SET application_name TO 'slon'; ");
+			adminfo->dbconn = dbconn;
+			if (db_exec_command(stmt, adminfo, &query) < 0)
+			{
+					printf("Unable to set application name ?!?\n");
+					return -1;
+			}
+			dstring_free(&query); 
+	}
 	/* ----
 	 * Commit the changes to the session settings.
 	 * ----
@@ -210,7 +244,7 @@ db_exec_command(SlonikStmt * stmt, SlonikAdmInfo * adminfo, SlonDString * query)
 
 	db_notice_stmt = stmt;
 
-	if (db_begin_xact(stmt, adminfo) < 0)
+	if (db_begin_xact(stmt, adminfo,false) < 0)
 		return -1;
 
 	res = PQexec(adminfo->dbconn, dstring_data(query));
@@ -247,7 +281,7 @@ db_exec_evcommand(SlonikStmt * stmt, SlonikAdmInfo * adminfo, SlonDString * quer
 
 	db_notice_stmt = stmt;
 
-	if (db_begin_xact(stmt, adminfo) < 0)
+	if (db_begin_xact(stmt, adminfo,false) < 0)
 		return -1;
 
 	res = PQexec(adminfo->dbconn, dstring_data(query));
@@ -294,7 +328,7 @@ db_exec_evcommand_p(SlonikStmt * stmt, SlonikAdmInfo * adminfo,
 
 	db_notice_stmt = stmt;
 
-	if (db_begin_xact(stmt, adminfo) < 0)
+	if (db_begin_xact(stmt, adminfo,false) < 0)
 		return -1;
 
 	res = PQexecParams(adminfo->dbconn, dstring_data(query),
@@ -338,7 +372,7 @@ db_exec_select(SlonikStmt * stmt, SlonikAdmInfo * adminfo, SlonDString * query)
 
 	db_notice_stmt = stmt;
 
-	if (db_begin_xact(stmt, adminfo) < 0)
+	if (db_begin_xact(stmt, adminfo,false) < 0)
 		return NULL;
 
 	res = PQexec(adminfo->dbconn, dstring_data(query));
@@ -369,7 +403,7 @@ db_get_nodeid(SlonikStmt * stmt, SlonikAdmInfo * adminfo)
 	SlonDString query;
 	int			no_id;
 
-	if (db_begin_xact(stmt, adminfo) < 0)
+	if (db_begin_xact(stmt, adminfo,false) < 0)
 		return -1;
 
 	dstring_init(&query);
@@ -406,7 +440,7 @@ db_get_version(SlonikStmt * stmt, SlonikAdmInfo * adminfo)
 	int         patch=0;
 	int         version=0;
 
-	if (db_begin_xact(stmt, adminfo) < 0)
+	if (db_begin_xact(stmt, adminfo,false) < 0)
 		return -1;
 
 	dstring_init(&query);
@@ -440,7 +474,7 @@ db_get_version(SlonikStmt * stmt, SlonikAdmInfo * adminfo)
  * ----------
  */
 int
-db_begin_xact(SlonikStmt * stmt, SlonikAdmInfo * adminfo)
+db_begin_xact(SlonikStmt * stmt, SlonikAdmInfo * adminfo, bool suppress_locking)
 {
 	PGresult   *res;
 
@@ -457,6 +491,34 @@ db_begin_xact(SlonikStmt * stmt, SlonikAdmInfo * adminfo)
 		return -1;
 	}
 	PQclear(res);
+	if(current_try_level > 0 && !suppress_locking)
+	{
+		/**
+		 * inside of a try block we obtain sl_event_lock
+		 * right away.  This is because if sometime later
+		 * in the try block needs sl_event_lock, it will
+		 * be running in the same transaction and will then
+		 * be too late to obtain the lock.
+		 */
+		SlonDString lock_query;
+		dstring_init(&lock_query);
+		slon_mkquery(&lock_query, "lock table \"_%s\".sl_event_lock; "
+					 ,stmt->script->clustername);
+		res = PQexec(adminfo->dbconn,dstring_data(&lock_query));
+		if (PQresultStatus(res) != PGRES_COMMAND_OK)
+		{
+			printf("%s:%d: lock table \"_%s\".sl_event_lock; - %s",
+				   stmt->stmt_filename, stmt->stmt_lno,
+				   stmt->script->clustername,
+				   PQresultErrorMessage(res));
+			PQclear(res);
+			adminfo->have_xact = true;
+			db_rollback_xact(stmt,adminfo);
+			return -1;
+		}
+		PQclear(res);
+		
+	}
 
 	adminfo->have_xact = true;
 
@@ -535,7 +597,7 @@ db_check_namespace(SlonikStmt * stmt, SlonikAdmInfo * adminfo, char *clustername
 	SlonDString query;
 	int			ntuples;
 
-	if (db_begin_xact(stmt, adminfo) < 0)
+	if (db_begin_xact(stmt, adminfo,false) < 0)
 		return -1;
 
 	dstring_init(&query);
@@ -568,7 +630,7 @@ db_check_requirements(SlonikStmt * stmt, SlonikAdmInfo * adminfo, char *clustern
 	SlonDString query;
 	int			ntuples;
 
-	if (db_begin_xact(stmt, adminfo) < 0)
+	if (db_begin_xact(stmt, adminfo,true) < 0)
 		return -1;
 
 	dstring_init(&query);
