@@ -56,67 +56,71 @@
      K_CREATE = 272,
      K_DROP = 273,
      K_ECHO = 274,
-     K_ERROR = 275,
-     K_EVENT = 276,
-     K_EXECUTE = 277,
-     K_EXIT = 278,
-     K_FAILOVER = 279,
-     K_FALSE = 280,
-     K_FILENAME = 281,
-     K_FINISH = 282,
-     K_FOR = 283,
-     K_FORWARD = 284,
-     K_FULL = 285,
-     K_FUNCTIONS = 286,
-     K_ID = 287,
-     K_INIT = 288,
-     K_KEY = 289,
-     K_LISTEN = 290,
-     K_LOCK = 291,
-     K_LOG = 292,
-     K_MERGE = 293,
-     K_MOVE = 294,
-     K_NAME = 295,
-     K_NEW = 296,
-     K_NO = 297,
-     K_NODE = 298,
-     K_OFF = 299,
-     K_OLD = 300,
-     K_OMIT = 301,
-     K_ON = 302,
-     K_ONLY = 303,
-     K_ORIGIN = 304,
-     K_PATH = 305,
-     K_PREPARE = 306,
-     K_PROVIDER = 307,
-     K_QUALIFIED = 308,
-     K_RECEIVER = 309,
-     K_REPAIR = 310,
-     K_RESTART = 311,
-     K_SCRIPT = 312,
-     K_SECONDS = 313,
-     K_SEQUENCE = 314,
-     K_SERVER = 315,
-     K_SET = 316,
-     K_STORE = 317,
-     K_SUBSCRIBE = 318,
-     K_SUCCESS = 319,
-     K_SWITCH = 320,
-     K_TABLE = 321,
-     K_TIMEOUT = 322,
-     K_TRUE = 323,
-     K_TRY = 324,
-     K_UNINSTALL = 325,
-     K_UNLOCK = 326,
-     K_UNSUBSCRIBE = 327,
-     K_UPDATE = 328,
-     K_YES = 329,
-     K_WAIT = 330,
-     K_SYNC = 331,
-     K_SLEEP = 332,
-     T_IDENT = 333,
-     T_LITERAL = 334,
-     T_NUMBER = 335
+     K_DATE = 275,
+     K_DFORMAT = 276,
+     K_ERROR = 277,
+     K_EVENT = 278,
+     K_EXECUTE = 279,
+     K_EXIT = 280,
+     K_FAILOVER = 281,
+     K_FALSE = 282,
+     K_FILENAME = 283,
+     K_FINISH = 284,
+     K_FOR = 285,
+     K_FORWARD = 286,
+     K_FULL = 287,
+     K_FUNCTIONS = 288,
+     K_ID = 289,
+     K_INIT = 290,
+     K_KEY = 291,
+     K_LISTEN = 292,
+     K_LOCK = 293,
+     K_LOG = 294,
+     K_MERGE = 295,
+     K_MOVE = 296,
+     K_NAME = 297,
+     K_NEW = 298,
+     K_NO = 299,
+     K_NODE = 300,
+     K_OFF = 301,
+     K_OLD = 302,
+     K_OMIT = 303,
+     K_ON = 304,
+     K_ONLY = 305,
+     K_ORIGIN = 306,
+     K_PATH = 307,
+     K_PREPARE = 308,
+     K_PROVIDER = 309,
+     K_QUALIFIED = 310,
+     K_RECEIVER = 311,
+     K_REPAIR = 312,
+     K_RESTART = 313,
+     K_SCRIPT = 314,
+     K_SECONDS = 315,
+     K_SEQUENCE = 316,
+     K_SERVER = 317,
+     K_SET = 318,
+     K_STORE = 319,
+     K_SUBSCRIBE = 320,
+     K_SUCCESS = 321,
+     K_SWITCH = 322,
+     K_TABLE = 323,
+     K_TABLES = 324,
+     K_SEQUENCES = 325,
+     K_TIMEOUT = 326,
+     K_TRUE = 327,
+     K_TRY = 328,
+     K_UNINSTALL = 329,
+     K_UNLOCK = 330,
+     K_UNSUBSCRIBE = 331,
+     K_UPDATE = 332,
+     K_YES = 333,
+     K_WAIT = 334,
+     K_SYNC = 335,
+     K_SLEEP = 336,
+     T_IDENT = 337,
+     T_LITERAL = 338,
+     T_NUMBER = 339
    };
 #endif
 /* Tokens.  */
@@ -137,67 +141,71 @@
 #define K_CREATE 272
 #define K_DROP 273
 #define K_ECHO 274
-#define K_ERROR 275
-#define K_EVENT 276
-#define K_EXECUTE 277
-#define K_EXIT 278
-#define K_FAILOVER 279
-#define K_FALSE 280
-#define K_FILENAME 281
-#define K_FINISH 282
-#define K_FOR 283
-#define K_FORWARD 284
-#define K_FULL 285
-#define K_FUNCTIONS 286
-#define K_ID 287
-#define K_INIT 288
-#define K_KEY 289
-#define K_LISTEN 290
-#define K_LOCK 291
-#define K_LOG 292
-#define K_MERGE 293
-#define K_MOVE 294
-#define K_NAME 295
-#define K_NEW 296
-#define K_NO 297
-#define K_NODE 298
-#define K_OFF 299
-#define K_OLD 300
-#define K_OMIT 301
-#define K_ON 302
-#define K_ONLY 303
-#define K_ORIGIN 304
-#define K_PATH 305
-#define K_PREPARE 306
-#define K_PROVIDER 307
-#define K_QUALIFIED 308
-#define K_RECEIVER 309
-#define K_REPAIR 310
-#define K_RESTART 311
-#define K_SCRIPT 312
-#define K_SECONDS 313
-#define K_SEQUENCE 314
-#define K_SERVER 315
-#define K_SET 316
-#define K_STORE 317
-#define K_SUBSCRIBE 318
-#define K_SUCCESS 319
-#define K_SWITCH 320
-#define K_TABLE 321
-#define K_TIMEOUT 322
-#define K_TRUE 323
-#define K_TRY 324
-#define K_UNINSTALL 325
-#define K_UNLOCK 326
-#define K_UNSUBSCRIBE 327
-#define K_UPDATE 328
-#define K_YES 329
-#define K_WAIT 330
-#define K_SYNC 331
-#define K_SLEEP 332
-#define T_IDENT 333
-#define T_LITERAL 334
-#define T_NUMBER 335
+#define K_DATE 275
+#define K_DFORMAT 276
+#define K_ERROR 277
+#define K_EVENT 278
+#define K_EXECUTE 279
+#define K_EXIT 280
+#define K_FAILOVER 281
+#define K_FALSE 282
+#define K_FILENAME 283
+#define K_FINISH 284
+#define K_FOR 285
+#define K_FORWARD 286
+#define K_FULL 287
+#define K_FUNCTIONS 288
+#define K_ID 289
+#define K_INIT 290
+#define K_KEY 291
+#define K_LISTEN 292
+#define K_LOCK 293
+#define K_LOG 294
+#define K_MERGE 295
+#define K_MOVE 296
+#define K_NAME 297
+#define K_NEW 298
+#define K_NO 299
+#define K_NODE 300
+#define K_OFF 301
+#define K_OLD 302
+#define K_OMIT 303
+#define K_ON 304
+#define K_ONLY 305
+#define K_ORIGIN 306
+#define K_PATH 307
+#define K_PREPARE 308
+#define K_PROVIDER 309
+#define K_QUALIFIED 310
+#define K_RECEIVER 311
+#define K_REPAIR 312
+#define K_RESTART 313
+#define K_SCRIPT 314
+#define K_SECONDS 315
+#define K_SEQUENCE 316
+#define K_SERVER 317
+#define K_SET 318
+#define K_STORE 319
+#define K_SUBSCRIBE 320
+#define K_SUCCESS 321
+#define K_SWITCH 322
+#define K_TABLE 323
+#define K_TABLES 324
+#define K_SEQUENCES 325
+#define K_TIMEOUT 326
+#define K_TRUE 327
+#define K_TRY 328
+#define K_UNINSTALL 329
+#define K_UNLOCK 330
+#define K_UNSUBSCRIBE 331
+#define K_UPDATE 332
+#define K_YES 333
+#define K_WAIT 334
+#define K_SYNC 335
+#define K_SLEEP 336
+#define T_IDENT 337
+#define T_LITERAL 338
+#define T_NUMBER 339
 
 
 
@@ -218,7 +226,7 @@ typedef union YYSTYPE
 
 
 /* Line 1676 of yacc.c  */
-#line 222 "y.tab.h"
+#line 230 "y.tab.h"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
