@@ -18,10 +18,11 @@
 #include <unistd.h>
 #include <sys/types.h>
 #include <sys/wait.h>
+#include <string.h>
 #endif
-#include "postgres.h"
-#include "libpq-fe.h"
 
+#include "libpq-fe.h"
+#include "../slonik/types.h"
 #include "slony_logshipper.h"
 
 
