@@ -14,7 +14,8 @@ sub add_node {
 		password => undef,
 		parent => undef,
 		noforward => undef,
-		sslmode => undef
+		sslmode => undef,
+		options => undef
 	       );
   my $K;
   while ($K= shift) {
@@ -66,6 +67,10 @@ sub add_node {
   if ($noforward) {
     $NOFORWARD[$node] = $noforward;
   }
+  my $options = $PARAMS{'options'};
+  if ($options) {
+    $OPTIONS[$node] = $options;
+  }
 }
 
 # This is the usual header to a slonik invocation that declares the
@@ -130,14 +135,31 @@ sub get_pid {
   return $pid;
 }
 
+sub get_node_name {
+  my ($node) = @_;
+  $node =~ /node(\d*)$/;
+  my $nodenum = $1;
+  my $nodename;
+  my $tnodename;
+  my ($dbname, $dbport, $dbhost) = ($DBNAME[$nodenum], $PORT[$nodenum], $HOST[$nodenum]);
+  my $command =  ps_args() . "| egrep \"[s]lon .*$CLUSTER_NAME \" | egrep \"host=$dbhost dbname=$dbname.*port=$dbport\" | sort -n | awk '{print \$15}'";
+  open(PSOUT, "$command|");
+  while ($tnodename = <PSOUT>) {
+    chomp $tnodename;
+    $nodename = $tnodename;
+  }
+  close(PSOUT);
+  return $nodename;
+}
+
 sub start_slon {
   my ($nodenum) = @_;
-  my ($dsn, $dbname) = ($DSN[$nodenum], $DBNAME[$nodenum]);
+  my ($dsn, $dbname, $opts) = ($DSN[$nodenum], $DBNAME[$nodenum], $OPTIONS[$nodenum]);
   $SYNC_CHECK_INTERVAL ||= 1000;
   $DEBUGLEVEL ||= 0;
   $LOG_NAME_SUFFIX ||= '%Y-%m-%d';
   system("mkdir -p $LOGDIR/slony1/node$nodenum");
-  my $cmd = "@@SLONBINDIR@@/slon -s $SYNC_CHECK_INTERVAL -d$DEBUGLEVEL $CLUSTER_NAME '$dsn' ";
+  my $cmd = "@@SLONBINDIR@@/slon -s $SYNC_CHECK_INTERVAL -d$DEBUGLEVEL $opts $CLUSTER_NAME '$dsn' ";
   my $logfilesuffix = POSIX::strftime( "$LOG_NAME_SUFFIX",localtime );
   chomp $logfilesuffix;
 
